﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;
using System;

//sound instance for all scenes
public class SoundManager : MonoBehaviour {

	//statics
	static SoundManager _instance;
	static public bool isActive{
		get{
			return _instance != null;
		}
	}
	//singleton for sound player
	static public SoundManager instance{
		get{
			if(_instance == null){
				_instance = GameObject.FindObjectOfType(typeof(SoundManager)) as SoundManager;
				if(_instance == null){
					GameObject obj = new GameObject("SoundManager");
					DontDestroyOnLoad(obj);
					_instance = obj.AddComponent<SoundManager>();
					obj.AddComponent<AudioSource>();
					obj.AddComponent<AudioSource>();
					obj.AddComponent<AudioSource>();
					_instance.init();
				}
			}
			return _instance;
		}
	}

	//audios function
	static public AudioSource[] allAudio;
	static public AudioSource audioBGM;
	static public AudioSource audioSFXOnce;
	static public AudioSource audioSFXLoop;

	//reset all sounds
	void init(){
		DontDestroyOnLoad(gameObject);
		allAudio = GetComponents<AudioSource>();
		audioBGM = allAudio[0];
		audioSFXLoop = allAudio[1];
		audioSFXOnce = allAudio[2];
//		readUserBGMPref ();
//		readUserSFXPref ();

	}

//	void readUserBGMPref(){
//		if(PlayerPrefs.GetInt(BaseID.BGM)==0){
//			_instance.unMuteBGM();
//		}else if(PlayerPrefs.GetInt(BaseID.BGM)==1){
//			_instance.setMuteBGM();
//		}
//	}
//	void readUserSFXPref(){
//		if(PlayerPrefs.GetInt(BaseID.SFX)==0){
//			_instance.unMuteSFXLoop();
//			_instance.unMuteSFXOnce();
//		}else if(PlayerPrefs.GetInt(BaseID.SFX)==1){
//			_instance.setMuteSFXLoop();
//			_instance.setMuteSFXOnce();
//		}
//	}

	//BGM Controller
	//playing bgm on loop
	public void playBGMLoop(AudioClip newBGM){
		if(!SoundSettings.bgmSetting){
			audioBGM.playOnAwake = true;
			audioBGM.loop = true;
			audioBGM.clip = newBGM;
			audioBGM.Play();
		}else{
			stopBGMLoop();
		}
	}
	//continue playing bgm after pause
	public void continueBGM(){
		audioBGM.Play();
	}
	//stop playing the BGM
	public void stopBGMLoop(){
		audioBGM.Stop();
	}
	//mute the bgm
	public void setMuteBGM(){
		audioBGM.mute = true;
	}
	//unmute the bgm
	public void unMuteBGM(){
		audioBGM.mute = false;
	}
	//SFX loop controller
	//playing the sfx on loop
	public void playSFXLoop(AudioClip newSFXLoop){
		audioSFXLoop.loop = true;
		audioSFXLoop.clip = newSFXLoop;
		audioSFXLoop.Play();
	}
	//mute the sfx
	public void setMuteSFXLoop(){
		audioSFXLoop.mute = true;
	}
	//unmute the sfx
	public void unMuteSFXLoop(){
		audioSFXLoop.mute = false;
	}
	//stop mute the sfx
	public void stopSFXLoop(){
		audioSFXLoop.Stop();
	}
	//SFX once controller
	//playing the SFX only once
	public void playSFXOnce(AudioClip newSFXOnce){
		if(!SoundSettings.sfxSetting)
			audioSFXOnce.PlayOneShot(newSFXOnce);
	}
	//mute the sfx 
	public void setMuteSFXOnce(){
		audioSFXOnce.mute = true;
	}
	//unmute the sfx
	public void unMuteSFXOnce(){
		audioSFXOnce.mute = false;
	}
	//get the file used for BGM
	public AudioClip getBGM(){
		return audioBGM.clip;
	}
}

public static class SoundSettings{
	public static bool bgmSetting;
	public static bool sfxSetting;
}